==> FreePastry-2.0b2_20070116-source.zip: pastry-2.0b2_20070116/src/rice/pastry/direct/SimulatorListener.java <==
/*******************************************************************************

"FreePastry" Peer-to-Peer Application Development Substrate

Copyright 2002-2007, Rice University. Copyright 2006-2007, Max Planck Institute 
for Software Systems.  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

- Neither the name of Rice  University (RICE), Max Planck Institute for Software 
Systems (MPI-SWS) nor the names of its contributors may be used to endorse or 
promote products derived from this software without specific prior written 
permission.

This software is provided by RICE, MPI-SWS and the contributors on an "as is" 
basis, without any representations or warranties of any kind, express or implied 
including, but not limited to, representations or warranties of 
non-infringement, merchantability or fitness for a particular purpose. In no 
event shall RICE, MPI-SWS or contributors be liable for any direct, indirect, 
incidental, special, exemplary, or consequential damages (including, but not 
limited to, procurement of substitute goods or services; loss of use, data, or 
profits; or business interruption) however caused and on any theory of 
liability, whether in contract, strict liability, or tort (including negligence
or otherwise) arising in any way out of the use of this software, even if 
advised of the possibility of such damage.

*******************************************************************************/ 
/*
 * Created on Dec 18, 2006
 */
package rice.pastry.direct;

import rice.p2p.commonapi.*;

/**
 * Notified for every message that is sent over the network.
 * 
 * to install this, call NetworkSimulator.addSimulatorListener().
 * 
 * @author Jeff Hoye
 */
public interface SimulatorListener {
  
  /**
   * Called for every message sent over the network.
   * 
   * @param m the Message that was sent.
   * @param from the source.
   * @param to the destination
   * @param delay when the message will be delivered (in millis)
   */
  public void messageSent(Message m, NodeHandle from, NodeHandle to, int delay);
}

==> FreePastry-2.1_20070529-source.zip: pastry-2.1_20070529/src/rice/pastry/direct/SimulatorListener.java <==
/*******************************************************************************

"FreePastry" Peer-to-Peer Application Development Substrate

Copyright 2002-2007, Rice University. Copyright 2006-2007, Max Planck Institute 
for Software Systems.  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

- Neither the name of Rice  University (RICE), Max Planck Institute for Software 
Systems (MPI-SWS) nor the names of its contributors may be used to endorse or 
promote products derived from this software without specific prior written 
permission.

This software is provided by RICE, MPI-SWS and the contributors on an "as is" 
basis, without any representations or warranties of any kind, express or implied 
including, but not limited to, representations or warranties of 
non-infringement, merchantability or fitness for a particular purpose. In no 
event shall RICE, MPI-SWS or contributors be liable for any direct, indirect, 
incidental, special, exemplary, or consequential damages (including, but not 
limited to, procurement of substitute goods or services; loss of use, data, or 
profits; or business interruption) however caused and on any theory of 
liability, whether in contract, strict liability, or tort (including negligence
or otherwise) arising in any way out of the use of this software, even if 
advised of the possibility of such damage.

*******************************************************************************/ 
/*
 * Created on Dec 18, 2006
 */
package rice.pastry.direct;

import rice.p2p.commonapi.*;

/**
 * Notified for every message that is sent over the network.
 * 
 * to install this, call NetworkSimulator.addSimulatorListener().
 * 
 * @author Jeff Hoye
 */
public interface SimulatorListener {
  
  /**
   * Called for every message sent over the network.
   * 
   * @param m the Message that was sent.
   * @param from the source.
   * @param to the destination
   * @param delay when the message will be delivered (in millis)
   */
  public void messageSent(Message m, NodeHandle from, NodeHandle to, int delay);
  
  /**
   * Called for every message received over the network.
   * 
   * @param m the Message that was sent.
   * @param from the source.
   * @param to the destination
   */
  public void messageReceived(Message m, NodeHandle from, NodeHandle to);
}
